==> carpet-addons-not-found-1.19.4-2.2.1-sources.jar: carpetaddonsnotfound/mixins/AnimalEntityMixin.java <==
package carpetaddonsnotfound.mixins;

import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

//#if MC<12002
import com.llamalad7.mixinextras.sugar.Local;
//#endif
import net.minecraft.class_1296;
import net.minecraft.class_1299;
import net.minecraft.class_1429;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_4466;

import static carpetaddonsnotfound.CarpetAddonsNotFoundSettings.beeBreedingCooldown;

@Mixin(class_1429.class)
public abstract class AnimalEntityMixin extends class_1296 {

  protected AnimalEntityMixin(class_1299<? extends class_1296> entityType,
                              class_1937 world) {
    super(entityType, world);
  }

  @Inject(method = "breed(Lnet/minecraft/server/world/ServerWorld;Lnet/minecraft/entity/passive/AnimalEntity;" +
                   //#if MC>11904
                   //$$ "Lnet/minecraft/entity/passive/PassiveEntity;" +
                   //#endif
                   ")V",
          at = @At(value = "TAIL"))
  private void setBeesBreedingAge(class_3218 world,
                                  class_1429 other,
                                  //#if MC>11904
                                  //$$ PassiveEntity baby,
                                  //#endif
                                  CallbackInfo ci
                                  //#if MC<12002
                                  , @Local class_1296 passiveEntity
                                  //#endif
  ) {
    boolean canSetBreedingAge =
            //#if MC<12002
            passiveEntity != null &&
            //#endif
            other instanceof class_4466;
    if (!canSetBreedingAge)
      return;

    this.method_5614(beeBreedingCooldown);
    other.method_5614(beeBreedingCooldown);
  }
}

==> carpet-addons-not-found-1.21.8-2.1.0-sources.jar: carpetaddonsnotfound/mixins/AnimalEntityMixin.java <==
package carpetaddonsnotfound.mixins;

import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

//#if MC<12002
//$$ import com.llamalad7.mixinextras.sugar.Local;
//#endif

import static carpetaddonsnotfound.CarpetAddonsNotFoundSettings.beeBreedingCooldown;

import net.minecraft.class_1296;
import net.minecraft.class_1299;
import net.minecraft.class_1429;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_4466;

@Mixin(class_1429.class)
public abstract class AnimalEntityMixin extends class_1296 {

  protected AnimalEntityMixin(class_1299<? extends class_1296> entityType,
                              class_1937 world) {
    super(entityType, world);
  }

  @Inject(method = "breed(Lnet/minecraft/server/world/ServerWorld;Lnet/minecraft/entity/passive/AnimalEntity;" +
                   //#if MC>11904
                   "Lnet/minecraft/entity/passive/PassiveEntity;" +
                   //#endif
                   ")V",
          at = @At(value = "TAIL"))
  private void setBeesBreedingAge(class_3218 world,
                                  class_1429 other,
                                  //#if MC>11904
                                  class_1296 baby,
                                  //#endif
                                  CallbackInfo ci
                                  //#if MC<12002
                                  //$$ , @Local PassiveEntity passiveEntity
                                  //#endif
  ) {
    boolean canSetBreedingAge =
            //#if MC<12002
            //$$ passiveEntity != null &&
            //#endif
            other instanceof class_4466;
    if (!canSetBreedingAge)
      return;

    this.method_5614(beeBreedingCooldown);
    other.method_5614(beeBreedingCooldown);
  }
}
